<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Security.Authentication.Identity.Core

Windows Runtime (WinRT) APIs for for the `Windows.Security.Authentication.Identity.Core` namespace.

This package provides the `winrt.windows.security.authentication.identity.core` module.
